Index: chrome/browser/extensions/extension_function_test_utils.h |
diff --git a/chrome/browser/extensions/extension_function_test_utils.h b/chrome/browser/extensions/extension_function_test_utils.h |
index f19d506fabd5b9e2eabfe78e03a5af113fd1e4a8..230d739768dd8eaf1cfb78c43e76dccd2c01368f 100644 |
--- a/chrome/browser/extensions/extension_function_test_utils.h |
+++ b/chrome/browser/extensions/extension_function_test_utils.h |
@@ -23,7 +23,7 @@ namespace extensions { |
class Extension; |
} |
// TODO(ckehoe): Accept args as scoped_ptr<base::Value>, |
// and migrate existing users to the new API. |
// This file is DEPRECATED. New tests should use the versions in |
// extensions/browser/api_test_utils.h. |
@@ -88,7 +88,7 @@ bool RunFunction(UIThreadExtensionFunction* function, |
Browser* browser, |
RunFunctionFlags flags); |
bool RunFunction(UIThreadExtensionFunction* function, |
- scoped_ptr<base::ListValue> args, |
+ std::unique_ptr<base::ListValue> args, |
Browser* browser, |
RunFunctionFlags flags); |
@@ -23,7 +23,7 @@ namespace extensions { |
class Extension; |
} |
-// TODO(ckehoe): Accept args as scoped_ptr<base::Value>, |
+// TODO(ckehoe): Accept args as std::unique_ptr<base::Value>, |
// and migrate existing users to the new API. |
// This file is DEPRECATED. New tests should use the versions in |